pub struct TtyEventSource { /* private fields */ }Expand description
Native Unix event source (raw terminal bytes → Event).
Manages terminal feature toggles by emitting the appropriate escape
sequences. Reads raw bytes from the tty fd, feeds them through
InputParser, and serves parsed events via poll_event/read_event.
Implementations